From: Feng Shu <tumashu@163.com>
To: Michael Rohleder <mike@rohleder.de>
Cc: 60271@debbugs.gnu.org
Subject: [bug#60271] [PATCH] gnu: Update xfce to 4.18.
Date: Sun, 01 Jan 2023 06:37:55 +0800 [thread overview]
Message-ID: <87ilhr19oc.fsf@163.com> (raw)
In-Reply-To: <87sfgvwsry.fsf_-_@rohleder.de> (Michael Rohleder's message of "Sat, 31 Dec 2022 15:29:37 +0100")
[-- Attachment #1: Type: text/plain, Size: 364 bytes --]
Michael Rohleder <mike@rohleder.de> writes:
I think we should conside update panel plugin when update to xfce 4.18.
for many panel plugins will build fail when we update xfce 4.18.
for example:
1. xfce4-cpufreq-plugin
2. xfce4-cpugraph-plugin
the below are patches, maybe we should create a wip-xfce branch, to see
which xfce apps or plugins wil build fail.
[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #2: 0001-gnu-thunar-Add-a-search-path-for-THUNARX_DIRS.patch --]
[-- Type: text/x-patch, Size: 1228 bytes --]
From 2dcd5344173c5249bf52c73efa0e89a081334813 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sat, 31 Dec 2022 17:09:57 +0800
Subject: [PATCH 01/12] gnu: thunar: Add a search path for THUNARX_DIRS.
* gnu/packages/xfce.scm (thunar)[native-search-paths]: Add THUNARX_DIRS
specification.
---
gnu/packages/xfce.scm | 6 ++++++
1 file changed, 6 insertions(+)
diff --git a/gnu/packages/xfce.scm b/gnu/packages/xfce.scm
index 32c6375c0e..34c8c4c7c2 100644
--- a/gnu/packages/xfce.scm
+++ b/gnu/packages/xfce.scm
@@ -728,6 +728,8 @@ (define-public thunar
(base32
"0rii7b2d0csvji24665h00nx0irg6rn6m9y8bkig9md45j0923ib"))))
(build-system gnu-build-system)
+ (arguments
+ '(#:configure-flags '("--with-custom-thunarx-dirs-enabled")))
(native-inputs
(list pkg-config intltool))
(inputs
@@ -741,6 +743,10 @@ (define-public thunar
pcre
xfce4-panel
startup-notification))
+ (native-search-paths
+ (list (search-path-specification
+ (variable "THUNARX_DIRS")
+ (files (list "lib/thunarx-3")))))
(home-page "https://www.xfce.org/")
(synopsis "Xfce file manager")
(description
--
2.38.1
[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #4: 0003-gnu-xfce4-cpufreq-plugin-Update-to-1.2.8.patch --]
[-- Type: text/x-patch, Size: 1276 bytes --]
From 74b3296fa8051f2650aaaaf51e1e0be097a5dbaa Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sun, 1 Jan 2023 06:04:23 +0800
Subject: [PATCH 03/12] gnu: xfce4-cpufreq-plugin: Update to 1.2.8.
* gnu/packages/xfce.scm (xfce4-cpufreq-plugin): Update to 1.2.8.
---
gnu/packages/xfce.scm | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/gnu/packages/xfce.scm b/gnu/packages/xfce.scm
index 87d70084f1..6d825cfe78 100644
--- a/gnu/packages/xfce.scm
+++ b/gnu/packages/xfce.scm
@@ -1577,7 +1577,7 @@ (define-public xfce4-calculator-plugin
(define-public xfce4-cpufreq-plugin
(package
(name "xfce4-cpufreq-plugin")
- (version "1.2.7")
+ (version "1.2.8")
(source (origin
(method url-fetch)
(uri (string-append "https://archive.xfce.org/src/panel-plugins/"
@@ -1586,7 +1586,7 @@ (define-public xfce4-cpufreq-plugin
"/xfce4-cpufreq-plugin-" version ".tar.bz2"))
(sha256
(base32
- "1365pj6viij492hq4mw34w4390sfdrn94rdgm2r1f6gma1hzpm2s"))))
+ "1sbkjphrlyyqsmdggq2624qr45wkkrmvczpv04h5fpkjykcmir07"))))
(build-system gnu-build-system)
(native-inputs
(list intltool pkg-config))
--
2.38.1
[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #5: 0004-gnu-xfce4-cpugraph-plugin-Update-to-1.2.7.patch --]
[-- Type: text/x-patch, Size: 1278 bytes --]
From f9aa50d9fc62d7a7129aa48d867e19a0b6af1afe Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sun, 1 Jan 2023 06:08:16 +0800
Subject: [PATCH 04/12] gnu: xfce4-cpugraph-plugin: Update to 1.2.7.
* gnu/packages/xfce.scm (xfce4-cpugraph-plugin): Update to 1.2.7.
---
gnu/packages/xfce.scm | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/gnu/packages/xfce.scm b/gnu/packages/xfce.scm
index 6d825cfe78..4180f21036 100644
--- a/gnu/packages/xfce.scm
+++ b/gnu/packages/xfce.scm
@@ -1444,7 +1444,7 @@ (define-public xfce4-volumed-pulse
(define-public xfce4-cpugraph-plugin
(package
(name "xfce4-cpugraph-plugin")
- (version "1.2.6")
+ (version "1.2.7")
(source (origin
(method url-fetch)
(uri (string-append "https://archive.xfce.org/src/panel-plugins/"
@@ -1453,7 +1453,7 @@ (define-public xfce4-cpugraph-plugin
"/xfce4-cpugraph-plugin-" version ".tar.bz2"))
(sha256
(base32
- "16dg8xdwzyy70sj8zkms3vnp0wdhmqbrq4fld1aah90qgkslcckp"))))
+ "01bl6glkwfvqvxm3sp3y4mb8szx7bnqnjns59sb8cwgdg3i539k8"))))
(build-system gnu-build-system)
(native-inputs
(list intltool pkg-config))
--
2.38.1
[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #6: 0005-gnu-xfce4-eyes-plugin-Update-to-4.6.0.patch --]
[-- Type: text/x-patch, Size: 1256 bytes --]
From 1b01593a18a07e36b81b832711cd99b06259ff8b Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sun, 1 Jan 2023 06:15:07 +0800
Subject: [PATCH 05/12] gnu: xfce4-eyes-plugin: Update to 4.6.0.
* gnu/packages/xfce.scm (xfce4-eyes-plugin): Update to 4.6.0.
---
gnu/packages/xfce.scm | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/gnu/packages/xfce.scm b/gnu/packages/xfce.scm
index 4180f21036..d16ed4f3d8 100644
--- a/gnu/packages/xfce.scm
+++ b/gnu/packages/xfce.scm
@@ -1475,7 +1475,7 @@ (define-public xfce4-cpugraph-plugin
(define-public xfce4-eyes-plugin
(package
(name "xfce4-eyes-plugin")
- (version "4.5.1")
+ (version "4.6.0")
(source (origin
(method url-fetch)
(uri (string-append "https://archive.xfce.org/src/panel-plugins/"
@@ -1484,7 +1484,7 @@ (define-public xfce4-eyes-plugin
"/xfce4-eyes-plugin-" version ".tar.bz2"))
(sha256
(base32
- "1iaszzkagl1mb0cdafrvlfjnjklhhs9y90517par34sjiqbq1dsd"))))
+ "092kmv2i0flg3zg622q0id70mz1kvlz27y12i5y3nfdsi1fz03xd"))))
(build-system gnu-build-system)
(native-inputs
(list intltool pkg-config))
--
2.38.1
[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #7: 0006-gnu-xfce4-whiskermenu-plugin-Update-to-2.7.1.patch --]
[-- Type: text/x-patch, Size: 1270 bytes --]
From aa7a05875cfcd8a9905b98ee3b68e7f4c7ae3981 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sun, 1 Jan 2023 06:16:46 +0800
Subject: [PATCH 06/12] gnu: xfce4-whiskermenu-plugin: Update to 2.7.1.
* gnu/packages/xfce.scm (xfce4-whiskermenu-plugin): Update to 2.7.1.
---
gnu/packages/xfce.scm | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/gnu/packages/xfce.scm b/gnu/packages/xfce.scm
index d16ed4f3d8..27e14e7994 100644
--- a/gnu/packages/xfce.scm
+++ b/gnu/packages/xfce.scm
@@ -518,7 +518,7 @@ (define-public xfce4-pulseaudio-plugin
(define-public xfce4-whiskermenu-plugin
(package
(name "xfce4-whiskermenu-plugin")
- (version "2.6.2")
+ (version "2.7.1")
(source
(origin
(method url-fetch)
@@ -526,7 +526,7 @@ (define-public xfce4-whiskermenu-plugin
"xfce4-whiskermenu-plugin/" (version-major+minor version) "/"
"xfce4-whiskermenu-plugin-" version ".tar.bz2"))
(sha256
- (base32 "0vppm85pvhsigg5d74nx7cixlsrsyfjagw6avrdclfjr30nf483d"))))
+ (base32 "0gm65h3xk6b9gm6maj7h4ikvn291iachsxlay5qfrmd0chbhrbh4"))))
(build-system cmake-build-system)
(native-inputs
(list pkg-config intltool))
--
2.38.1
[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #8: 0007-gnu-xfce4-places-plugin-Update-to-1.8.3.patch --]
[-- Type: text/x-patch, Size: 1286 bytes --]
From c8d91eafeb128f44c12ba6342d27318ef268612f Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sun, 1 Jan 2023 06:22:12 +0800
Subject: [PATCH 07/12] gnu: xfce4-places-plugin: Update to 1.8.3.
* gnu/packages/xfce.scm (xfce4-places-plugin): Update to 1.8.3.
---
gnu/packages/xfce.scm | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/gnu/packages/xfce.scm b/gnu/packages/xfce.scm
index 27e14e7994..a3bd49ce43 100644
--- a/gnu/packages/xfce.scm
+++ b/gnu/packages/xfce.scm
@@ -1843,7 +1843,7 @@ (define-public xfce4-netload-plugin
(define-public xfce4-places-plugin
(package
(name "xfce4-places-plugin")
- (version "1.8.2")
+ (version "1.8.3")
(source (origin
(method url-fetch)
(uri (string-append "https://archive.xfce.org/src/panel-plugins/"
@@ -1852,7 +1852,7 @@ (define-public xfce4-places-plugin
"/xfce4-places-plugin-" version ".tar.bz2"))
(sha256
(base32
- "00bh7d91vzk6s38djlpnihvjvymxgrnx3nh6sm2y3mnx2jmb4chy"))))
+ "0hy7c350x1p1grj517l1x0r8b4asbcv7sl3b5qnb0apj0dnhw7gi"))))
(build-system gnu-build-system)
(native-inputs
(list intltool desktop-file-utils pkg-config))
--
2.38.1
[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #9: 0008-gnu-xfce4-systemload-plugin-Update-to-1.3.2.patch --]
[-- Type: text/x-patch, Size: 1293 bytes --]
From d6c23994c8bfe1d36f27d9037ce39c62e55eac83 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sun, 1 Jan 2023 06:24:28 +0800
Subject: [PATCH 08/12] gnu: xfce4-systemload-plugin: Update to 1.3.2.
* gnu/packages/xfce.scm (xfce4-systemload-plugin): Update to 1.3.2.
---
gnu/packages/xfce.scm | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/gnu/packages/xfce.scm b/gnu/packages/xfce.scm
index a3bd49ce43..7c3755d59f 100644
--- a/gnu/packages/xfce.scm
+++ b/gnu/packages/xfce.scm
@@ -1959,7 +1959,7 @@ (define-public xfce4-stopwatch-plugin
(define-public xfce4-systemload-plugin
(package
(name "xfce4-systemload-plugin")
- (version "1.3.1")
+ (version "1.3.2")
(source (origin
(method url-fetch)
(uri (string-append "https://archive.xfce.org/src/panel-plugins/"
@@ -1968,7 +1968,7 @@ (define-public xfce4-systemload-plugin
"/xfce4-systemload-plugin-" version ".tar.bz2"))
(sha256
(base32
- "0lknh5l30qs5c69wwjcblbyhczvdbxs59fqkb8mpqbfm05w01lan"))))
+ "0wmh09w5fnm9srbr6r4gpdima738szqcp3qbzb8kl18f0b1kyc5v"))))
(build-system gnu-build-system)
(native-inputs
(list intltool pkg-config))
--
2.38.1
[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #10: 0009-gnu-Add-thunar-archive-plugin.patch --]
[-- Type: text/x-patch, Size: 1547 bytes --]
From 02867f7495bff23e112819acd476818f472db839 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Mon, 21 Mar 2022 19:29:10 +0800
Subject: [PATCH 09/12] gnu: Add thunar-archive-plugin.
* gnu/packages/xfce.scm (thunar-archive-plugin): New variable.
---
gnu/packages/xfce.scm | 21 +++++++++++++++++++++
1 file changed, 21 insertions(+)
diff --git a/gnu/packages/xfce.scm b/gnu/packages/xfce.scm
index 7c3755d59f..9abc630eb2 100644
--- a/gnu/packages/xfce.scm
+++ b/gnu/packages/xfce.scm
@@ -781,6 +781,27 @@ (define-public thunar-volman
and import the new pictures from your camera.")
(license gpl2+)))
+(define-public thunar-archive-plugin
+ (package
+ (name "thunar-archive-plugin")
+ (version "0.5.0")
+ (source
+ (origin
+ (method url-fetch)
+ (uri (string-append "https://archive.xfce.org/src/thunar-plugins/"
+ name "/" (version-major+minor version)
+ "/" name "-" version ".tar.bz2"))
+ (sha256
+ (base32 "1ykg6qj65l5wywpbiiabidjxzvrhv6q4v63jxb6mlai8b2iqijlf"))))
+ (build-system gnu-build-system)
+ (native-inputs (list pkg-config intltool))
+ (inputs (list exo thunar gtk+))
+ (home-page "https://www.xfce.org/")
+ (synopsis "Archive plugin for Thunar file manager")
+ (description "The Thunar Archive Plugin allows you to create and extract
+archive files using the file context menus in the Thunar file manager.")
+ (license gpl2+)))
+
(define-public xfwm4
(package
(name "xfwm4")
--
2.38.1
[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #11: 0010-gnu-Add-thunar-shares-plugin.patch --]
[-- Type: text/x-patch, Size: 1595 bytes --]
From 5c46975946ab2be81e3fcc8b00fda7a79e4761c0 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Mon, 21 Mar 2022 19:30:30 +0800
Subject: [PATCH 10/12] gnu: Add thunar-shares-plugin.
* gnu/packages/xfce.scm (thunar-shares-plugin): New variable.
---
gnu/packages/xfce.scm | 22 ++++++++++++++++++++++
1 file changed, 22 insertions(+)
diff --git a/gnu/packages/xfce.scm b/gnu/packages/xfce.scm
index 9abc630eb2..287cf3be85 100644
--- a/gnu/packages/xfce.scm
+++ b/gnu/packages/xfce.scm
@@ -802,6 +802,28 @@ (define-public thunar-archive-plugin
archive files using the file context menus in the Thunar file manager.")
(license gpl2+)))
+(define-public thunar-shares-plugin
+ (package
+ (name "thunar-shares-plugin")
+ (version "0.3.1")
+ (source
+ (origin
+ (method url-fetch)
+ (uri (string-append "https://archive.xfce.org/src/thunar-plugins/"
+ name "/" (version-major+minor version)
+ "/" name "-" version ".tar.bz2"))
+ (sha256
+ (base32 "182j8jl91735004hbl0i2xxga4r6fk03srfl6g87czkjm9y8q7fw"))))
+ (build-system gnu-build-system)
+ (native-inputs (list pkg-config intltool))
+ (inputs (list thunar gtk+))
+ (home-page "https://www.xfce.org/")
+ (synopsis "Folder share plugin for Thunar file manager")
+ (description
+ "The Thunar Shares Plugin allows you to quickly share a folder using
+Samba from Thunar (the Xfce file manager) without requiring root access.")
+ (license gpl2+)))
+
(define-public xfwm4
(package
(name "xfwm4")
--
2.38.1
[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #12: 0011-gnu-Add-thunar-media-tags-plugin.patch --]
[-- Type: text/x-patch, Size: 1918 bytes --]
From 0d72724dc3d741945295342df153414c201387a0 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Mon, 21 Mar 2022 19:31:43 +0800
Subject: [PATCH 11/12] gnu: Add thunar-media-tags-plugin.
* gnu/packages/xfce.scm (thunar-media-tags-plugin): New variable.
---
gnu/packages/xfce.scm | 23 +++++++++++++++++++++++
1 file changed, 23 insertions(+)
diff --git a/gnu/packages/xfce.scm b/gnu/packages/xfce.scm
index 287cf3be85..9688682672 100644
--- a/gnu/packages/xfce.scm
+++ b/gnu/packages/xfce.scm
@@ -54,6 +54,7 @@ (define-module (gnu packages xfce)
#:use-module (gnu packages libcanberra)
#:use-module (gnu packages linux)
#:use-module (gnu packages mate)
+ #:use-module (gnu packages mp3)
#:use-module (gnu packages pcre)
#:use-module (gnu packages pdf)
#:use-module (gnu packages photo)
@@ -824,6 +825,28 @@ (define-public thunar-shares-plugin
Samba from Thunar (the Xfce file manager) without requiring root access.")
(license gpl2+)))
+(define-public thunar-media-tags-plugin
+ (package
+ (name "thunar-media-tags-plugin")
+ (version "0.3.0")
+ (source
+ (origin
+ (method url-fetch)
+ (uri (string-append "https://archive.xfce.org/src/thunar-plugins/"
+ name "/" (version-major+minor version)
+ "/" name "-" version ".tar.bz2"))
+ (sha256
+ (base32 "06sr7b4p9f585gian8vpx7j0pkzg0vvwcrjmrhvh7i5sb90w8rg2"))))
+ (build-system gnu-build-system)
+ (native-inputs (list pkg-config intltool))
+ (inputs (list exo gtk+ thunar taglib))
+ (home-page "https://www.xfce.org/")
+ (synopsis "Media tags plugin for Thunar file manager")
+ (description
+ "Media tags plugin allows tags editing from Thunar file manager and
+tags-based file renaming from inside Thunar Bulk Renamer.")
+ (license gpl2+)))
+
(define-public xfwm4
(package
(name "xfwm4")
--
2.38.1
[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #13: 0012-gnu-Add-thunar-vcs-plugin.patch --]
[-- Type: text/x-patch, Size: 2587 bytes --]
From f30c65f1abb7f1f375d21468ec3e1ede8ef8494f Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Mon, 21 Mar 2022 19:33:59 +0800
Subject: [PATCH 12/12] gnu: Add thunar-vcs-plugin.
* gnu/packages/xfce.scm (thunar-vcs-plugin): New variable.
---
gnu/packages/xfce.scm | 39 +++++++++++++++++++++++++++++++++++++++
1 file changed, 39 insertions(+)
diff --git a/gnu/packages/xfce.scm b/gnu/packages/xfce.scm
index 9688682672..af8f8e1060 100644
--- a/gnu/packages/xfce.scm
+++ b/gnu/packages/xfce.scm
@@ -35,6 +35,7 @@
(define-module (gnu packages xfce)
#:use-module (gnu artwork)
#:use-module (gnu packages)
+ #:use-module (gnu packages apr)
#:use-module (gnu packages base)
#:use-module (gnu packages bash)
#:use-module (gnu packages calendar)
@@ -65,6 +66,8 @@ (define-module (gnu packages xfce)
#:use-module (gnu packages python-xyz)
#:use-module (gnu packages pulseaudio)
#:use-module (gnu packages search)
+ #:use-module (gnu packages textutils)
+ #:use-module (gnu packages version-control)
#:use-module (gnu packages web)
#:use-module (gnu packages wm)
#:use-module (gnu packages xml)
@@ -847,6 +850,42 @@ (define-public thunar-media-tags-plugin
tags-based file renaming from inside Thunar Bulk Renamer.")
(license gpl2+)))
+(define-public thunar-vcs-plugin
+ (package
+ (name "thunar-vcs-plugin")
+ (version "0.2.0")
+ (source
+ (origin
+ (method url-fetch)
+ (uri (string-append "https://archive.xfce.org/src/thunar-plugins/"
+ name "/" (version-major+minor version)
+ "/" name "-" version ".tar.bz2"))
+ (sha256
+ (base32 "1f2d1dwfyi6xv3qkd8l8xh0vhz8wh0601cyigjzn426lqga1d29n"))))
+ (build-system gnu-build-system)
+ (arguments
+ (list #:configure-flags
+ #~(list (string-append "CPPFLAGS=-I"
+ #$(this-package-input "apr-util")
+ "/include/apr-1"))))
+ (native-inputs (list pkg-config intltool utf8proc))
+ (inputs
+ (list exo
+ gtk+
+ thunar
+ libxfce4util
+ apr
+ apr-util
+ subversion
+ git))
+ (home-page "https://www.xfce.org/")
+ (synopsis "VCS plugin for Thunar file manager")
+ (description
+ "Thunar VCS Plugin (formerly known as Thunar SVN Plugin) gives SVN and
+GIT integration to Thunar, it adds Subversion and GIT actions to the context
+menu.")
+ (license gpl2+)))
+
(define-public xfwm4
(package
(name "xfwm4")
--
2.38.1
[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #3: 0002-gnu-xfce-Propagate-search-paths-of-thunar.patch --]
[-- Type: text/x-patch, Size: 1041 bytes --]
From 06fb7367c4d8ee4b1428d125acd441e174004bfb Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sat, 31 Dec 2022 17:15:38 +0800
Subject: [PATCH 02/12] gnu: xfce: Propagate search paths of 'thunar'.
* gnu/packages/xfce.scm (xfce)[native-search-paths]: Add thunar.
---
gnu/packages/xfce.scm | 6 ++++--
1 file changed, 4 insertions(+), 2 deletions(-)
diff --git a/gnu/packages/xfce.scm b/gnu/packages/xfce.scm
index 34c8c4c7c2..87d70084f1 100644
--- a/gnu/packages/xfce.scm
+++ b/gnu/packages/xfce.scm
@@ -1111,8 +1111,10 @@ (define-public xfce
;; Default font that applications such as IceCat require.
(list font-dejavu))
(native-search-paths
- ;; For finding panel plugins.
- (package-native-search-paths xfce4-panel))
+ ;; For finding panel and thunar plugins.
+ (append
+ (package-native-search-paths xfce4-panel)
+ (package-native-search-paths thunar)))
(home-page "https://www.xfce.org/")
(synopsis "Desktop environment (meta-package)")
(description
--
2.38.1
[-- Attachment #14: Type: text/plain, Size: 7 bytes --]
--
next prev parent reply other threads:[~2022-12-31 22:39 UTC|newest]
Thread overview: 33+ messages / expand[flat|nested] mbox.gz Atom feed top
2022-12-23 12:04 [bug#60271] [PATCH] gnu: Update xfce to 4.18 Michael Rohleder
2022-12-23 12:07 ` [bug#60271] [PATCH] gnu: libxfce4util: Update to 4.18.0 Michael Rohleder
2022-12-23 12:07 ` [bug#60271] [PATCH] gnu: xfconf: " Michael Rohleder
2022-12-23 12:07 ` [bug#60271] [PATCH] gnu: libxfce4ui: " Michael Rohleder
2022-12-23 12:07 ` [bug#60271] [PATCH] gnu: exo: " Michael Rohleder
2022-12-23 12:07 ` [bug#60271] [PATCH] gnu: tumbler: " Michael Rohleder
2022-12-23 12:07 ` [bug#60271] [PATCH] gnu: garcon: " Michael Rohleder
2022-12-23 12:07 ` [bug#60271] [PATCH] gnu: xfce4-panel: " Michael Rohleder
2022-12-23 12:07 ` [bug#60271] [PATCH] gnu: xfce4-appfinder: " Michael Rohleder
2022-12-23 12:07 ` [bug#60271] [PATCH] gnu: xfce4-session: " Michael Rohleder
2022-12-23 12:07 ` [bug#60271] [PATCH] gnu: xfce4-settings: Update to 4.18.1 Michael Rohleder
2022-12-23 12:07 ` [bug#60271] [PATCH] gnu: thunar: " Michael Rohleder
2022-12-23 12:07 ` [bug#60271] [PATCH] gnu: thunar-volman: Update to 4.18.0 Michael Rohleder
2022-12-23 12:07 ` [bug#60271] [PATCH] gnu: xfwm4: " Michael Rohleder
2022-12-23 12:08 ` [bug#60271] [PATCH] gnu: xfdesktop: " Michael Rohleder
2022-12-23 12:08 ` [bug#60271] [PATCH] gnu: xfce4-power-manager: " Michael Rohleder
2022-12-23 12:08 ` [bug#60271] [PATCH] gnu: xfce4-dev-tools: " Michael Rohleder
2022-12-23 18:12 ` [bug#60271] [PATCH] gnu: Update xfce to 4.18 Kaelyn via Guix-patches via
2022-12-25 23:40 ` Feng Shu
2022-12-26 16:08 ` Michael Rohleder
2022-12-26 19:26 ` [bug#60271] " tumashu
2022-12-26 22:04 ` Feng Shu
2022-12-27 10:11 ` Michael Rohleder
2022-12-27 10:40 ` [bug#60271] " tumashu
2022-12-31 6:56 ` Feng Shu
2022-12-31 14:29 ` Michael Rohleder
2022-12-31 22:37 ` Feng Shu [this message]
2023-01-28 9:04 ` 宋文武 via Guix-patches via
2023-01-28 9:50 ` Feng Shu
2023-01-28 10:09 ` Michael Rohleder
[not found] ` <87r0ve5972.fsf_-_@envs.net>
2023-01-30 13:19 ` [bug#60271] xfce 4.18 issues: gsettings, icons missing, and logout need long time Feng Shu
2023-01-19 20:40 ` [bug#60271] [PATCH] gnu: Update xfce to 4.18 Kaelyn via Guix-patches via
2023-01-28 11:49 ` [bug#60271] [PATCH 1/4] gnu: thunar-shares-plugin: Update to 0.3.2 tumashu
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
List information: https://guix.gnu.org/
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=87ilhr19oc.fsf@163.com \
--to=tumashu@163.com \
--cc=60271@debbugs.gnu.org \
--cc=mike@rohleder.de \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
Code repositories for project(s) associated with this public inbox
https://git.savannah.gnu.org/cgit/guix.git
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).